%GRADIENT   Gradient vector of an image.
%   GRADIENT(A,SIGMA) returns the gradient vector of a real valued,
%   scalar image. SIGMA is the Gaussian smoothing. The returned type
%   is an N-by-1 tensor image, where N is the dimensionality of A.

% (C) Copyright 1999-2007               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Bernd Rieger, August 2000.
% Cris Luengo, 21 September 2000: SIGMA is now allowed to be any size vector.
% July 2007, call to gauss_derivative instead to low-level code directly (BR)
% 10 October 2007: Removed logic concerning SIGMA parameter, DERIVATIVE takes
%                  care of that. (CL)

function out = gradient(in,sigma)

if nargin < 2
   sigma = 1;
end
if ~isnumeric(sigma)
   error('Sigma parameter must be numeric.')
   % This assures that IN is a dip_image
end
if ~isscalar(in)
   error('Input image must be scalar.')
end
if ~isreal(in.data)
   error('Input image must be real.')
end

dim = ndims(in);
out = dip_image('array',[dim,1]);
for ii = 1:dim
   parOrder = zeros(dim,1);
   parOrder(ii) = 1;
   out(ii) = derivative(in,sigma,parOrder);
end
