%CHANGE_XYZ   Change the whitepoint of the XYZ colorspace
%
% SYNOPSIS:
%  image_out = change_xyz(image_in, new_xyz)
%
% DEFAULTS:
%  new_xyz = [0.9505 1 1.0888]  (D65 white)
%
% DESCRIPTION:
%  The whitepoint of the input image is changed into the new value (XYZ_new).
%  This is done by assuming that the values in CIELAB should be the same for
%  the input image with the old reference white and the output image with
%  the new reference white.
%  Note the difference with SET_XYZ. In CHANGE_XYZ the pixel values of the
%  input image are changed due to the change in the white reference, whereas
%  in SET_XYZ only the reference white is changed.

% (C) Copyright 1999-2007               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Judith Dijk, June 2002.
% 20 October 2007: Moved to toolbox directory. (CL)

function out = change_xyz(in, XYZ_out)
% Avoid being in menu
if nargin == 1 & ischar(in) & strcmp(in,'DIP_GetParamList')
   out = struct('menu','none');
   return
end

if ~isa(in,'dip_image_array') | ~iscolor(in)
   error('Input needs to be a color image.');
end

ori_col = colorspace(in);
xyz = colorspace(in,'xyz');

XYZ_in = get_xyz(in);
if( nargin < 2)
   XYZ_out = [.9505 1 1.0888]; % standard d65-2
end

out = in;
xyz{1} = xyz{1}*(XYZ_out(1)/XYZ_in(1));
xyz{2} = xyz{2}*(XYZ_out(2)/XYZ_in(2));
xyz{2} = xyz{3}*(XYZ_out(3)/XYZ_in(3));

xyz = set_xyz(xyz,XYZ_out);
out = colorspace(xyz,ori_col);
